@@ -411,12 +411,14 @@ current layout defined in `dirvish-layout-recipes'."
   [:description
    (lambda () (dirvish--format-menu-heading
           "Dirvish main menu"
-          "NOTICE: these commands require relevant Dirvish extensions"))
+          "NOTICE: these commands require relevant Dirvish extensions")
+     (declare-function dirvish-narrow "dirvish-narrow"))
    "" "Actions & Essential commands"
    ("u" "User interface setup"   dirvish-setup-menu)
    ("c" "Dired cheatsheet"       dirvish-dired-cheatsheet)
-   ("/" "Perform fd search"      dirvish-fd)
-   ("@" "Find all dirs by fd"    dirvish-fd-jump)
+   ("/" "Run fd search here"     dirvish-fd)
+   ("#" "Search everything in ~" (lambda () (interactive)
+                                   (dirvish-fd "~" "") (dirvish-narrow)))
    ("R" "Rsync marked files"     dirvish-rsync)
    ("n" "Live narrowing"         dirvish-narrow)
    "Transient commands"
