@@ -1,11 +1,11 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "dirvish" "2.3.0"
+(define-package "dirvish" "20250504.807"
   "A modern file manager based on dired mode."
   '((emacs  "28.1")
     (compat "30"))
   :url "https://github.com/alexluigit/dirvish"
-  :commit "cd235f87ecd67c9195e3e857b4ea313f258c8457"
-  :revdesc "cd235f87ecd6"
+  :commit "d877433f957a363ad78b228e13a8e5215f2d6593"
+  :revdesc "d877433f957a"
   :keywords '("files" "convenience")
   :authors '(("Alex Lu" . "https://github.com/alexluigit"))
   :maintainers '(("Alex Lu" . "https://github.com/alexluigit")))
